California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROPOSITION 005 - CHANGES REQUIREMENTS FOR CERTAIN PROPERTY OWNERS TO TRANSFER THEIR PROPERTY TAX BASE TO REPLACEMENT PROPERTY. INITIATIVE CONSTITUTIONAL AMENDMENT AND STATUTE. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1407354 | NO ON PROP 5, SPONSORED BY EDUCATORS, PUBLIC SAFETY, HEALTH CARE AND LOCAL GOVERNMENT ORGANIZATIONS | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1400190 | YES ON 5 COMMITTEE, SPONSORED BY THE CALIFORNIA ASSOCIATION OF REALTORS | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1411207 | MILLION VOTER PROJECT ACTION FUND, NO ON 5 YES ON 10, SPONSORED BY SOCIAL JUSTICE ORGANIZATIONS | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1411917 | MILLION VOTER PROJECT ACTION FUND, NO ON 5, SPONSORED BY SOCIAL JUSTICE ORGANIZATIONS | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1412754 | EAST BAY HOUSING ORGANIZATIONS (NON PROFIT 501C3) - YES ON PROPS 1, 2 & 10 & NO ON PROP 5 | OPPOSE